==> imce-3.0.11.tar.gz: imce/src/Plugin/ImcePlugin/Upload.php <==
<?php

namespace Drupal\imce\Plugin\ImcePlugin;

use Drupal\Core\File\FileSystemInterface;
use Drupal\imce\ImcePluginBase;
use Drupal\imce\ImceFM;

/**
 * Defines Imce Upload plugin.
 *
 * @ImcePlugin(
 *   id = "upload",
 *   label = "Upload",
 *   weight = -10,
 *   operations = {
 *     "upload" = "opUpload"
 *   }
 * )
 */
class Upload extends ImcePluginBase {

  /**
   * {@inheritdoc}
   */
  public function permissionInfo() {
    return [
      'upload_files' => $this->t('Upload files'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildPage(array &$page, ImceFM $fm) {
    if ($fm->hasPermission('upload_files')) {
      $page['#attached']['library'][] = 'imce/drupal.imce.upload';
    }
  }

  /**
   * Operation handler: upload.
   */
  public function opUpload(ImceFM $fm) {
    $folder = $fm->activeFolder;
    if (!$folder || !$folder->getPermission('upload_files')) {
      return;
    }
    // Prepare save options.
    $destination = $folder->getUri();
    $replace = $fm->getConf('replace', FileSystemInterface::EXISTS_RENAME);
    $validators = [];
    // Extension validator.
    $exts = $fm->getConf('extensions', '');
    if ($exts === '*') {
      $exts = NULL;
    }
    $constraints = class_exists('\Drupal\file\Plugin\Validation\Constraint\FileExtensionConstraint');
    if ($constraints) {
      $validators['FileExtension'] = ['extensions' => $exts];
    }
    else {
      $validators['file_validate_extensions'] = [$exts];
    }
    // File size and user quota validator.
    if ($constraints) {
      $validators['FileSizeLimit'] = [
        'fileLimit' => $fm->getConf('maxsize'),
        'userLimit' => $fm->getConf('quota'),
      ];
    }
    else {
      $validators['file_validate_size'] = [
        $fm->getConf('maxsize'),
        $fm->getConf('quota'),
      ];
    }
    // Image resolution validator.
    $width = $fm->getConf('maxwidth');
    $height = $fm->getConf('maxheight');
    if ($width || $height) {
      // Fix exif orientation before resizing.
      if (function_exists('exif_orientation_validate_image_rotation')) {
        $validators['exif_orientation_validate_image_rotation'] = [];
      }
      $dims = ($width ?: 10000) . 'x' . ($height ?: 10000);
      if ($constraints) {
        $validators['FileImageDimensions'] = ['maxDimensions' => $dims];
      }
      else {
        $validators['file_validate_image_resolution'] = [$dims];
      }
    }
    // Name validator.
    $validators['imce_file_validate_name'] = [$fm->getNameFilter()];
    // Save files.
    if ($files = file_save_upload('imce', $validators, $destination, NULL, $replace)) {
      $fs = \Drupal::service('file_system');
      foreach (array_filter($files) as $file) {
        // Set status and save.
        $file->setPermanent();
        $file->save();
        // Add to the folder and to js response.
        $name = $fs->basename($file->getFileUri());
        $item = $folder->addFile($name);
        $item->uuid = $file->uuid();
        $item->addToJs();
      }
    }
  }

}

==> imce-3.1.0.tar.gz: imce/src/Plugin/ImcePlugin/Upload.php <==
<?php

namespace Drupal\imce\Plugin\ImcePlugin;

use Drupal\Core\File\FileSystemInterface;
use Drupal\imce\ImceFM;
use Drupal\imce\ImcePluginBase;

/**
 * Defines Imce Upload plugin.
 *
 * @ImcePlugin(
 *   id = "upload",
 *   label = "Upload",
 *   weight = -10,
 *   operations = {
 *     "upload" = "opUpload"
 *   }
 * )
 */
class Upload extends ImcePluginBase {

  /**
   * {@inheritdoc}
   */
  public function permissionInfo() {
    return [
      'upload_files' => $this->t('Upload files'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildPage(array &$page, ImceFM $fm) {
    if ($fm->hasPermission('upload_files')) {
      $page['#attached']['library'][] = 'imce/drupal.imce.upload';
    }
  }

  /**
   * Operation handler: upload.
   */
  public function opUpload(ImceFM $fm) {
    $folder = $fm->activeFolder;
    if (!$folder || !$folder->getPermission('upload_files')) {
      return;
    }
    // Prepare save options.
    $destination = $folder->getUri();
    $replace = $fm->getConf('replace', FileSystemInterface::EXISTS_RENAME);
    $validators = [];
    $exts = $fm->getConf('extensions', '');
    if ($exts === '*') {
      $exts = NULL;
    }
    $width = $fm->getConf('maxwidth');
    $height = $fm->getConf('maxheight');
    $dims = $width || $height ? ($width ?: 10000) . 'x' . ($height ?: 10000) : '';
    $maxsize = $fm->getConf('maxsize');
    $quota = $fm->getConf('quota');
    // Fix exif orientation before resizing.
    if ($dims && function_exists('exif_orientation_validate_image_rotation')) {
      $validators['exif_orientation_validate_image_rotation'] = [];
    }
    if (class_exists('Drupal\file\Plugin\Validation\Constraint\FileExtensionConstraint')) {
      $validators['ImceFileName'] = ['filter' => $fm->getNameFilter()];
      $validators['FileExtension'] = ['extensions' => $exts];
      $validators['FileSizeLimit'] = [
        'fileLimit' => $maxsize,
        'userLimit' => $quota,
      ];
      if ($dims) {
        $validators['FileImageDimensions'] = ['maxDimensions' => $dims];
      }
    }
    else {
      $validators['imce_file_validate_name'] = [$fm->getNameFilter()];
      $validators['file_validate_extensions'] = [$exts];
      $validators['file_validate_size'] = [$maxsize, $quota];
      if ($dims) {
        $validators['file_validate_image_resolution'] = [$dims];
      }
    }
    // Save files.
    $files = file_save_upload('imce', $validators, $destination, NULL, $replace);
    if ($files) {
      $fs = \Drupal::service('file_system');
      foreach (array_filter($files) as $file) {
        // Set status and save.
        $file->setPermanent();
        $file->save();
        // Add to the folder and to js response.
        $name = $fs->basename($file->getFileUri());
        $item = $folder->addFile($name);
        $item->uuid = $file->uuid();
        $item->addToJs();
      }
    }
  }

}
